package com.diagbot.web;

import com.diagbot.dto.RespDTO;
import com.diagbot.entity.node.Indication;
import com.diagbot.entity.node.IndicationConcept;
import com.diagbot.entity.node.IndicationCondition;
import com.diagbot.facade.IndicationManFacade;
import com.diagbot.vo.ConceptIndexVO;
import com.diagbot.vo.ConditionIndexVO;
import com.diagbot.vo.IndicationPageVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * @Description:
 * @Author:zhaops
 * @time: 2020/11/17 13:56
 */
@RestController
@RequestMapping("/indicationman")
@Api(value = "开单合理项维护相关API", tags = { "开单合理项维护相关API" })
@SuppressWarnings("unchecked")
public class IndicationManController {
    @Autowired
    IndicationManFacade indicationManFacade;

    @ApiOperation(value = "获取开单合理项列表[zhaops]",
            notes = "number:页码<br>" +
                    "size:每页条目数<br>" +
                    "types:术语类型（多选）1-检验套餐、2-检查、3-检查子项、4-手术和操作、5-药品注册名<br>" +
                    "conceptName:术语名称（模糊匹配）<br>" +
                    "conditionName:条件明细（模糊匹配）<br>" +
                    "relationStatus:启用禁用标志（0-禁用，1-启用）<br>")
    @PostMapping("/getPage")
    public RespDTO<Indication> getPage(@RequestBody IndicationPageVO indicationPageVO) {
        Page<Indication> data = indicationManFacade.getPage(indicationPageVO);
        return RespDTO.onSuc(data);
    }

    @ApiOperation(value = "条件明细检索[zhaops]",
            notes = "type:开单类型（1-检验套餐、2-检查、3-检查子项、4-手术和操作、5-药品注册名）<br>" +
                    "conceptName:开单项<br>" +
                    "ruleType:规则类型：文本类型、数值类型<br>" +
                    "conditionName:条件明细（模糊匹配）<br>")
    @PostMapping("/conditionIndex")
    public RespDTO<IndicationCondition> conditionIndex(@RequestBody ConditionIndexVO conditionIndexVO) {
        List<IndicationCondition> data = indicationManFacade.conditionIndex(conditionIndexVO);
        return RespDTO.onSuc(data);
    }

    @ApiOperation(value = "开单项检索[zhaops]",
            notes = "type:开单类型（1-检验套餐、2-检查、3-检查子项、4-手术和操作、5-药品注册名）<br>" +
                    "conceptName:开单项（模糊匹配）<br>")
    @PostMapping("/conceptIndex")
    public RespDTO<IndicationConcept> conceptIndex(@RequestBody ConceptIndexVO conceptIndexVO) {
        List<IndicationConcept> data = indicationManFacade.conceptIndex(conceptIndexVO);
        return RespDTO.onSuc(data);
    }
}